#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2008 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using System.Collections.Generic;
using System.Text;

namespace HeuristicLab.PluginInfrastructure {
  /// <summary>
  /// Enumerator of available file types for a plugin.
  /// </summary>
  public enum PluginFileType {
    Assembly,
    NativeAssembly,
    Data,
    License
  };

  /// <summary>
  /// PluginFileAttribute can be used to declare which files make up an plugin.
  /// Multiple files can be associated to an plugin. Each file should be associated to only one plugin.
  /// </summary>
  [AttributeUsage(AttributeTargets.Class, AllowMultiple = true)]
  public class PluginFileAttribute : System.Attribute {
    private string filename;

    /// <summary>
    /// Gets or sets the filename of the plugin.
    /// </summary>
    public string Filename {
      get { return filename; }
      //set { filename = value; }
    }

    private PluginFileType filetype = PluginFileType.Data;

    /// <summary>
    /// Gets or sets the filetype of the plugin file.
    /// </summary>
    public PluginFileType Filetype {
      get { return filetype; }
      //set { filetype = value; }
    }

    /// <summary>
    /// Initializes a new instance of <see cref="PluginFileAttribute"/>.
    /// <param name="filename">Name of the file</param>
    /// <param name="type">Type of the file (Assembly, Executable, Data, License)</param>
    /// </summary>
    public PluginFileAttribute(string filename, PluginFileType type) {
      this.filename = filename;
      this.filetype = type;
    }
  }
}
